==> elemental2-webgl-1.0.0-b15-7a28038.jar: elemental2/webgl/WEBGL_draw_buffers.java <==
package elemental2.webgl;

import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class WEBGL_draw_buffers {
  public double COLOR_ATTACHMENT0_WEBGL;
  public double COLOR_ATTACHMENT10_WEBGL;
  public double COLOR_ATTACHMENT11_WEBGL;
  public double COLOR_ATTACHMENT12_WEBGL;
  public double COLOR_ATTACHMENT13_WEBGL;
  public double COLOR_ATTACHMENT14_WEBGL;
  public double COLOR_ATTACHMENT15_WEBGL;
  public double COLOR_ATTACHMENT1_WEBGL;
  public double COLOR_ATTACHMENT2_WEBGL;
  public double COLOR_ATTACHMENT3_WEBGL;
  public double COLOR_ATTACHMENT4_WEBGL;
  public double COLOR_ATTACHMENT5_WEBGL;
  public double COLOR_ATTACHMENT6_WEBGL;
  public double COLOR_ATTACHMENT7_WEBGL;
  public double COLOR_ATTACHMENT8_WEBGL;
  public double COLOR_ATTACHMENT9_WEBGL;
  public double DRAW_BUFFER0_WEBGL;
  public double DRAW_BUFFER10_WEBGL;
  public double DRAW_BUFFER11_WEBGL;
  public double DRAW_BUFFER12_WEBGL;
  public double DRAW_BUFFER13_WEBGL;
  public double DRAW_BUFFER14_WEBGL;
  public double DRAW_BUFFER15_WEBGL;
  public double DRAW_BUFFER1_WEBGL;
  public double DRAW_BUFFER2_WEBGL;
  public double DRAW_BUFFER3_WEBGL;
  public double DRAW_BUFFER4_WEBGL;
  public double DRAW_BUFFER5_WEBGL;
  public double DRAW_BUFFER6_WEBGL;
  public double DRAW_BUFFER7_WEBGL;
  public double DRAW_BUFFER8_WEBGL;
  public double DRAW_BUFFER9_WEBGL;
  public double MAX_COLOR_ATTACHMENTS_WEBGL;
  public double MAX_DRAW_BUFFERS_WEBGL;

  public native void drawBuffersWEBGL(double[] buffers);
}

==> elemental2-webgl-1.2.0.jar: elemental2/webgl/WEBGL_draw_buffers.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.webgl;

import elemental2.core.JsArray;
import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class WEBGL_draw_buffers {
  public double COLOR_ATTACHMENT0_WEBGL;
  public double COLOR_ATTACHMENT10_WEBGL;
  public double COLOR_ATTACHMENT11_WEBGL;
  public double COLOR_ATTACHMENT12_WEBGL;
  public double COLOR_ATTACHMENT13_WEBGL;
  public double COLOR_ATTACHMENT14_WEBGL;
  public double COLOR_ATTACHMENT15_WEBGL;
  public double COLOR_ATTACHMENT1_WEBGL;
  public double COLOR_ATTACHMENT2_WEBGL;
  public double COLOR_ATTACHMENT3_WEBGL;
  public double COLOR_ATTACHMENT4_WEBGL;
  public double COLOR_ATTACHMENT5_WEBGL;
  public double COLOR_ATTACHMENT6_WEBGL;
  public double COLOR_ATTACHMENT7_WEBGL;
  public double COLOR_ATTACHMENT8_WEBGL;
  public double COLOR_ATTACHMENT9_WEBGL;
  public double DRAW_BUFFER0_WEBGL;
  public double DRAW_BUFFER10_WEBGL;
  public double DRAW_BUFFER11_WEBGL;
  public double DRAW_BUFFER12_WEBGL;
  public double DRAW_BUFFER13_WEBGL;
  public double DRAW_BUFFER14_WEBGL;
  public double DRAW_BUFFER15_WEBGL;
  public double DRAW_BUFFER1_WEBGL;
  public double DRAW_BUFFER2_WEBGL;
  public double DRAW_BUFFER3_WEBGL;
  public double DRAW_BUFFER4_WEBGL;
  public double DRAW_BUFFER5_WEBGL;
  public double DRAW_BUFFER6_WEBGL;
  public double DRAW_BUFFER7_WEBGL;
  public double DRAW_BUFFER8_WEBGL;
  public double DRAW_BUFFER9_WEBGL;
  public double MAX_COLOR_ATTACHMENTS_WEBGL;
  public double MAX_DRAW_BUFFERS_WEBGL;

  public native void drawBuffersWEBGL(JsArray<Double> buffers);

  @JsOverlay
  public final void drawBuffersWEBGL(double[] buffers) {
    drawBuffersWEBGL(Js.<JsArray<Double>>uncheckedCast(buffers));
  }
}
